// functions for DLL functions.  defined for easy import into Labview and other programs

#define ERR_LOAD_DLL  1   // Failed to open SX20.DLL.
#define ERR_FUNCADDR  2   // Failed to find function name in SX20.DLL.

// Bit flags returned by GetErrFlags().
#define ERR_KERNEL_DRIVER   0x00000001      //  Can't open driver.
#define ERR_DEVICE_NOT_FOUND  0x00000002      //  Can't detect board.
#define ERR_INTERRUPT     0x00000004      //  Error enabling interrupt.
#define ERR_THREAD        0x00000008      //  Error starting a thread.
#define ERR_VERSION       0x00000010      //  Driver version not supported.


typedef void  (* FPTR)( unsigned long index );    // Pointer to application's interrupt callback function.

///////////////////////////////////////////////////////////////////////////////////
// Pointers to functions that are exported by SX20.DLL.
///////////////////////////////////////////////////////////////////////////////////

#ifdef USING_LOADLIBRARY_METHOD
unsigned long (__stdcall *SX20_AddressGet)(unsigned long index);
unsigned long (__stdcall *SX20_ErrFlagsGet)(unsigned long index);
void (__stdcall *SX20_BoardOpen)(unsigned long index, unsigned long idx, FPTR callback);// Note: index is same value as idx
void (__stdcall *SX20_BoardClose)(unsigned long index);
void (__stdcall *SX20_BoardIenSet)(unsigned long index, unsigned long enable);
DWORD (__stdcall *SX20_BoardIenGet)(unsigned long index);
void (__stdcall *SX20_BoardReset)(unsigned long index);
void (__stdcall *SX20_Init)(void);
void (__stdcall *SX20_Shutdown)(void);

// Direct register access functions.
unsigned long (__stdcall *SX20_PortDwordGet)(unsigned long index, unsigned long addr);
void (__stdcall *SX20_PortDwordSet)(unsigned long index, unsigned long addr, unsigned long value);

// Digital I/O functions.
unsigned long (__stdcall *SX20_ChanArmGet)(unsigned long index, unsigned long chan);
void (__stdcall *SX20_ChanArmSet)(unsigned long index, unsigned long chan, unsigned long enable);
unsigned long (__stdcall *SX20_ChanCapGet)( unsigned long index, unsigned long chan);
unsigned long (__stdcall *SX20_ChanDioGet)( unsigned long index, unsigned long chan);
void (__stdcall *SX20_ChanDioSet)(unsigned long index, unsigned long chan, unsigned long state);
unsigned long (__stdcall *SX20_ChanEdgeGet)( unsigned long index, unsigned long chan);
void (__stdcall *SX20_ChanEdgeSet)(unsigned long index, unsigned long chan, unsigned long edges);
unsigned long (__stdcall *SX20_ChanIenGet)(unsigned long index, unsigned long chan);
void (__stdcall *SX20_ChanIenSet)(unsigned long index, unsigned long chan, unsigned long enable);
unsigned long (__stdcall *SX20_ChanIrqGet)(unsigned long index, unsigned long chan);
unsigned long (__stdcall *SX20_GroupDioGet)(unsigned long index, unsigned long group);
void (__stdcall *SX20_GroupDioSet)(unsigned long index, unsigned long group, unsigned long states);
unsigned long (__stdcall *SX20_OctetDdrGet)(unsigned long index, unsigned long octet);
void (__stdcall *SX20_OctetDdrSet)(unsigned long index, unsigned long octet, unsigned long outmode);
unsigned long (__stdcall *SX20_LoeGet)(unsigned long index);
void (__stdcall *SX20_LoeSet)(unsigned long index, unsigned long enable);

#else
// Status and control functions.
__declspec(dllimport) unsigned long __stdcall SX20_AddressGet(unsigned long index);
__declspec(dllimport) unsigned long __stdcall SX20_ErrFlagsGet(unsigned long index);
__declspec(dllimport) void __stdcall SX20_BoardOpen(unsigned long index, unsigned long idx, FPTR callback);// Note: index is same value as idx
__declspec(dllimport) void __stdcall SX20_BoardClose(unsigned long index);
__declspec(dllimport) void __stdcall SX20_BoardIenSet(unsigned long index, unsigned long enable);
__declspec(dllimport) DWORD __stdcall SX20_BoardIenGet(unsigned long index);
__declspec(dllimport) void __stdcall SX20_BoardReset(unsigned long index);
__declspec(dllimport) void __stdcall SX20_Init(void);
__declspec(dllimport) void __stdcall SX20_Shutdown(void);

// Direct register access functions.
__declspec(dllimport) unsigned long __stdcall SX20_PortDwordGet(unsigned long index, unsigned long addr);
__declspec(dllimport) void __stdcall SX20_PortDwordSet(unsigned long index, unsigned long addr, unsigned long value);

// Digital I/O functions.
__declspec(dllimport) unsigned long __stdcall SX20_ChanArmGet(unsigned long index, unsigned long chan);
__declspec(dllimport) void __stdcall SX20_ChanArmSet(unsigned long index, unsigned long chan, unsigned long enable);
__declspec(dllimport) unsigned long __stdcall SX20_ChanCapGet   ( unsigned long index, unsigned long chan);
__declspec(dllimport) unsigned long __stdcall SX20_ChanDioGet   ( unsigned long index, unsigned long chan);
__declspec(dllimport) void __stdcall SX20_ChanDioSet   ( unsigned long index, unsigned long chan, unsigned long state);
__declspec(dllimport) unsigned long __stdcall SX20_ChanEdgeGet  ( unsigned long index, unsigned long chan);
__declspec(dllimport) void __stdcall SX20_ChanEdgeSet(unsigned long index, unsigned long chan, unsigned long edges);
__declspec(dllimport) unsigned long __stdcall SX20_ChanIenGet(unsigned long index, unsigned long chan);
__declspec(dllimport) void __stdcall SX20_ChanIenSet(unsigned long index, unsigned long chan, unsigned long enable);
__declspec(dllimport) unsigned long __stdcall SX20_ChanIrqGet(unsigned long index, unsigned long chan);
__declspec(dllimport) unsigned long __stdcall SX20_GroupDioGet(unsigned long index, unsigned long group);
__declspec(dllimport) void __stdcall SX20_GroupDioSet (unsigned long index, unsigned long group, unsigned long states);
__declspec(dllimport) unsigned long __stdcall SX20_OctetDdrGet (unsigned long index, unsigned long octet);
__declspec(dllimport) void __stdcall SX20_OctetDdrSet (unsigned long index, unsigned long octet, unsigned long outmode);
__declspec(dllimport) unsigned long __stdcall SX20_LoeGet (unsigned long index);
__declspec(dllimport) void __stdcall SX20_LoeSet     (unsigned long index, unsigned long enable);
#endif